Index: src/interpreter/bytecode-array-builder.h |
diff --git a/src/interpreter/bytecode-array-builder.h b/src/interpreter/bytecode-array-builder.h |
index f20d66882b2e0e0895a45cd6dd6ace70e50712ae..833e26b5a2e6896a9c63eecb34207c472fe6ba4f 100644 |
--- a/src/interpreter/bytecode-array-builder.h |
+++ b/src/interpreter/bytecode-array-builder.h |
@@ -148,9 +148,10 @@ class BytecodeArrayBuilder final : public ZoneObject { |
// Create a new context with size |slots|. |
BytecodeArrayBuilder& CreateFunctionContext(int slots); |
- // Creates a new context for a with-statement with the |object| in a register |
- // and the closure in the accumulator. |
- BytecodeArrayBuilder& CreateWithContext(Register object); |
+ // Creates a new context with the given |scope_info| for a with-statement |
+ // with the |object| in a register and the closure in the accumulator. |
+ BytecodeArrayBuilder& CreateWithContext(Register object, |
+ Handle<ScopeInfo> scope_info); |
// Create a new arguments object in the accumulator. |
BytecodeArrayBuilder& CreateArguments(CreateArgumentsType type); |